@@ -15,7 +15,7 @@
  */
 
 use super::*;
-use dmntk_feel::FeelDateTime;
+use dmntk_feel_parser::dmntk_feel::FeelDateTime;
 
 #[test]
 fn test_addition() {
