@@ -14,10 +14,7 @@
  * SOFTWARE.
  */
 
-extern crate dmntk_examples;
-extern crate dmntk_feel_parser;
-extern crate dmntk_model;
-extern crate dmntk_recognizer;
+pub extern crate dmntk_recognizer;
 #[macro_use]
 extern crate lazy_static;
 extern crate regex;
