@@ -15,9 +15,9 @@
  */
 
 use self::errors::*;
-use dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
-use dmntk_feel_parser::dmntk_feel::FeelType;
-use dmntk_model::model::*;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::FeelType;
+use dmntk_recognizer::dmntk_model::model::*;
 use std::borrow::Borrow;
 use std::collections::{BTreeMap, HashMap};
 
@@ -160,7 +160,7 @@ impl Enricher {
 
 /// Definition of errors raised by [enricher](crate::model::enricher) module.
 mod errors {
-  use dmntk_feel_parser::dmntk_feel::dmntk_common::DmntkError;
+  use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::dmntk_common::DmntkError;
 
   /// Errors raised by [Enricher].
   #[derive(Debug, PartialEq)]
