@@ -14,7 +14,7 @@
  * SOFTWARE.
  */
 
-use dmntk_feel_parser::dmntk_feel::dmntk_common::DmntkError;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::dmntk_common::DmntkError;
 
 /// Errors related to model evaluation.
 #[derive(Debug, PartialEq)]
