@@ -15,11 +15,11 @@
  */
 
 use crate::model::errors::*;
-use dmntk_feel_parser::dmntk_feel::context::FeelContext;
-use dmntk_feel_parser::dmntk_feel::dmntk_common::{Result, Stringify};
-use dmntk_feel_parser::dmntk_feel::values::{Value, VALUE_NULL};
-use dmntk_feel_parser::dmntk_feel::Name;
-use dmntk_model::model::{Decision, Definitions, DmnElement, InputData, NamedElement};
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::context::FeelContext;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::dmntk_common::{Result, Stringify};
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::values::{Value, VALUE_NULL};
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::Name;
+use dmntk_recognizer::dmntk_model::model::{Decision, Definitions, DmnElement, InputData, NamedElement};
 use std::collections::HashMap;
 
 ///
@@ -189,9 +189,11 @@ pub fn build_extractor_from_input_data(input_data: &InputData) -> Result<NameVal
 #[cfg(test)]
 mod tests {
   use crate::model::eval::ModelEvaluator;
-  use dmntk_feel_parser::dmntk_feel::context::FeelContext;
-  use dmntk_feel_parser::dmntk_feel::values::{Value, VALUE_NULL};
-  use dmntk_feel_parser::dmntk_feel::Name;
+  use dmntk_recognizer::dmntk_model;
+  use dmntk_recognizer::dmntk_model::dmntk_examples;
+  use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::context::FeelContext;
+  use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::values::{Value, VALUE_NULL};
+  use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::Name;
 
   #[test]
   pub fn test_build_extractor_from_input_data_string() {
