@@ -16,10 +16,10 @@
 
 use crate::model::errors::*;
 use crate::model::eval::ModelEvaluator;
-use dmntk_feel_parser::dmntk_feel::context::FeelContext;
-use dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
-use dmntk_feel_parser::dmntk_feel::values::Value;
-use dmntk_model::model::*;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::context::FeelContext;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::values::Value;
+use dmntk_recognizer::dmntk_model::model::*;
 
 /// Evaluates a [Decision] defined by specified name.
 ///
