@@ -15,10 +15,10 @@
  */
 
 use crate::model::errors::*;
-use dmntk_feel_parser::dmntk_feel::context::FeelContext;
-use dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
-use dmntk_feel_parser::dmntk_feel::values::{Value, VALUE_NULL};
-use dmntk_model::model::Definitions;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::context::FeelContext;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::values::{Value, VALUE_NULL};
+use dmntk_recognizer::dmntk_model::model::Definitions;
 
 /// Evaluates a decision service specified by name.
 pub fn evaluate_decision_service_by_name(definitions: &Definitions, name: &str, _ctx: &FeelContext) -> Result<Value> {
