@@ -15,11 +15,12 @@
  */
 
 use crate::model::errors::*;
-use dmntk_feel_parser::dmntk_feel::context::FeelContext;
-use dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
-use dmntk_feel_parser::dmntk_feel::values::{Value, Values, VALUE_NULL_WITH_TRACE};
-use dmntk_feel_parser::dmntk_feel::{AstNode, Name, OptAstNode, Scope};
-use dmntk_model::model::{BuiltinAggregator, DecisionTable, HitPolicy};
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::context::FeelContext;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::values::{Value, Values, VALUE_NULL_WITH_TRACE};
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::{AstNode, Name, OptAstNode, Scope};
+use dmntk_recognizer::dmntk_model::model::{BuiltinAggregator, DecisionTable, HitPolicy};
 
 /// Parsed rule of decision table.
 struct ParsedRule {
