@@ -14,9 +14,9 @@
  * SOFTWARE.
  */
 
-use dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
-use dmntk_feel_parser::dmntk_feel::values::Value;
-use dmntk_feel_parser::dmntk_feel::Scope;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::values::Value;
+use dmntk_recognizer::dmntk_model::dmntk_feel_parser::dmntk_feel::Scope;
 
 pub(crate) mod enricher;
 mod errors;
